@@ -118,6 +118,14 @@ nlmixr2NlmeControl <- function(maxIter = 100, pnlsMaxIter = 100, msMaxIter = 100
   .ret
 }
 
+#' @export
+rxUiDeparse.nlmeControl <- function(object, var) {
+  .default <- nlmeControl()
+  .w <- .deparseDifferent(.default, object, "genRxControl")
+  .deparseFinal(.default, object, .w, var)
+}
+
+
 #' @rdname nlmixr2NlmeControl
 #' @export
 nlmeControl <- nlmixr2NlmeControl
