@@ -362,7 +362,7 @@ nmObjGet.foceiThetaEtaParameters <- function(x, ...) {
     warning("some duplicate columns were dropped", call.=FALSE)
     .ret <- .ret[, -.dups]
   }
-  .ret
+  .addLevels(fit, .ret)
 }
 
 .calcShrinkOnly <- function(fit, thetaEtaParameters=fit$foceiThetaEtaParameters) {
@@ -371,6 +371,61 @@ nmObjGet.foceiThetaEtaParameters <- function(x, ...) {
   .ret[, -dim(.omega)[1] - 1]
 }
 
+#' Add Levels to Data Based on Fit Object
+#'
+#' This function modifies a data frame by adding levels to a specified
+#' variable based on the levels defined in a fit$ui$levels
+#'
+#' @param fit A list object that contains a `ui` element with `levels`
+#'   to be added to the data.
+#' @param data A data frame that will be modified by adding levels to
+#'   one or more of its variables.
+#' @return A modified data frame with levels added to the specified
+#'   variables. If the variable's values are out of the defined range,
+#'   they are set to `NA`.
+#' @details The function checks if the `fit` object contains
+#'   levels.
+#'
+#' If levels are present, it iterates through them and modifies the
+#' corresponding variable in the data frame:
+#'
+#' - Converts the variable to integer type.
+#'
+#' - Sets values less than 1 to `NA_integer_`.
+#'
+#' - Sets values greater than the number of levels to `NA_integer_`.
+#'
+#' - Assigns the levels and sets the class of the variable to
+#'   "factor".
+#'
+#'
+#' @author Matthew L. Fidler
+#'
+#' @noRd
+.addLevels <- function(fit, data) {
+  .levels <-  fit$ui$levels
+  if (!is.null(.levels)) {
+    for (i in seq_along(.levels)) {
+      .cur <- .levels[[i]] # language expression of levels() declaration
+      .var <- deparse1(.cur[[2]][[2]]) # levels variable
+      .w <- which(names(data) == .var) # does one of the output
+                                       # variables match?
+      if (length(.w) == 1) {
+        # now change to a factor
+        data[[.var]] <- as.integer(data[[.var]])
+        .w <- which(data[[.var]] < 1L)
+        data[[.var]][.w] <- NA_integer_
+        .lvls <- eval(.cur[[3]])
+        .w <- which(data[[.var]] > length(.lvls))
+        data[[.var]][.w] <- NA_integer_
+        attr(data[[.var]], "levels") <- .lvls
+        attr(data[[.var]], "class") <- "factor"
+      }
+    }
+  }
+  data
+}
+
 .calcTables <- function(fit, data=fit$dataSav, thetaEtaParameters=fit$foceiThetaEtaParameters,
                         table=tableControl(), keep=NULL) {
   keep <- unique(c(keep, "nlmixrRowNums"))
@@ -416,6 +471,7 @@ nmObjGet.foceiThetaEtaParameters <- function(x, ...) {
     warning("some duplicate columns were dropped", call.=FALSE)
     .ret <- .ret[, -.dups]
   }
+  .ret[[1]] <- .addLevels(fit, .ret[[1]])
   .ret
 }
 
@@ -471,8 +527,11 @@ nmObjGet.foceiThetaEtaParameters <- function(x, ...) {
 #' print(f)
 #'
 #' }
-addTable <- function(object, updateObject = FALSE, data=object$dataSav, thetaEtaParameters=object$foceiThetaEtaParameters,
-                     table=tableControl(), keep=NULL, drop=NULL,
+addTable <- function(object, updateObject = FALSE,
+                     data=object$dataSav,
+                     thetaEtaParameters=object$foceiThetaEtaParameters,
+                     table=tableControl(),
+                     keep=NULL, drop=NULL,
                      envir = parent.frame(1)) {
   assignInMyNamespace(".finalUiCompressed", FALSE)
   on.exit(assignInMyNamespace(".finalUiCompressed", TRUE))
@@ -637,7 +696,26 @@ tableControl <- function(npde = NULL,
   checkmate::assertLogical(covariates, len=1, any.missing=FALSE)
   checkmate::assertLogical(addDosing, len=1, any.missing=FALSE)
   checkmate::assertLogical(subsetNonmem, len=1, any.missing=FALSE)
-  checkmate::assertCharacter(keep, null.ok=TRUE)
+  checkmate::assertCharacter(keep, null.ok=TRUE, pattern = "^[.]*[a-zA-Z]+[a-zA-Z0-9._]*$",
+                             any.missing = FALSE,min.chars=1)
+  .invalidKeep <- c("id", "sim.id", "resetno", "time", "nlmixrRowNums")
+  .invalidKeep <- intersect(tolower(keep), tolower(.invalidKeep))
+  if (length(.invalidKeep) > 0) {
+    .w <- which(tolower(keep) %in% .invalidKeep)
+    keep <- keep[-.w]
+    warning("'keep' contains ", paste(.invalidKeep, collapse=", "), "\nwhich are output when needed, ignoring these items", call.=FALSE)
+  }
+  .invalidKeep <- c("evid",  "ss", "amt", "rate", "dur", "ii")
+  .invalidKeep <- intersect(tolower(keep), tolower(.invalidKeep))
+  if (length(.invalidKeep) > 0) {
+    stop("'keep' cannot contain ", paste(.invalidKeep, collapse=", "), "\nconsider using addDosing=TRUE or merging to original dataset\nfor a fit the merge can be called by fit$dataMergeLeft fit$dataMergeRight or fit$dataMergeInner", call.=FALSE)
+  }
+  .invalidKeep <- c ("rxLambda", "rxYj", "rxLow", "rxHi")
+  .invalidKeep <- intersect(tolower(keep), tolower(.invalidKeep))
+  if (length(.invalidKeep) > 0) {
+    stop("'keep' cannot contain ", paste(.invalidKeep, collapse=", "), call.=FALSE)
+  }
+
   checkmate::assertCharacter(drop, null.ok=TRUE)
   if (inherits(censMethod, "character")) {
     .censMethod <- setNames(c("truncated-normal"=3L, "cdf"=2L, "omit"=1L, "pred"=5L, "ipred"=4L, "epred"=6L)[match.arg(censMethod)], NULL)
@@ -657,3 +735,10 @@ tableControl <- function(npde = NULL,
   class(.ret) <- "tableControl"
   return(.ret)
 }
+
+#' @export
+rxUiDeparse.tableControl <- function(object, var) {
+  .default <- tableControl()
+  .w <- .deparseDifferent(.default, object, "genRxControl")
+  .deparseFinal(.default, object, .w, var)
+}
