@@ -20,7 +20,7 @@
 #'
 #' \donttest{
 #'
-#' if (rxode2parse::.linCmtSens()) {
+#' if (rxode2::.linCmtSensB()) {
 #'
 #' one.cmt <- function() {
 #'  ini({
@@ -100,13 +100,21 @@ vpcSim <- function(object, ..., keep=NULL, n=300,
   .si$dfObs <- NULL
   .si$returnType <- "data.frame.TBS"
   .sim <- do.call(rxode2::rxSolve, .si)
+  if (!("sim.id" %in% names(.sim))) {
+    .sim2$sim.id <- 1
+  }
   # now look for how many have missing values
   .w <- which(is.na(.sim$ipred))
   .nretry <- 0
   while (length(.w) > 0 && .nretry < nretry) {
     .w <- which(is.na(.sim$ipred))
     .simIds <- unique(.sim$sim.id[.w])
-    .sim <- .sim[!(.sim$sim.id %in% .simIds), ]
+    .sim <- .sim[!(.sim$sim.id %in% .simIds),, drop = FALSE]
+    if (length(.sim$sim.id) == 0) {
+      warning("when filtering for simulations, could not find any though some were flagged, be cautious with results",
+              call.=FALSE)
+      break
+    }
     .sim$sim.id <- as.integer(factor(.sim$sim.id))
     .mx <- max(.sim$sim.id)
     .si$nsim <- n - .mx
@@ -116,6 +124,9 @@ vpcSim <- function(object, ..., keep=NULL, n=300,
       .adjust <- TRUE
     }
     .sim2 <- do.call(rxode2::rxSolve, .si)
+    if (!("sim.id" %in% names(.sim2))) {
+      .sim2$sim.id <- .simIds[1]
+    }
     if (.adjust) {
       # Select simulations without NA ipreds in them
       .w <- which(is.na(.sim2$ipred))
